==> localnews-activity-model-1.2.0-sources.jar: com/bxm/localnews/activity/vo/PrivilegeVO.java <==
package com.bxm.localnews.activity.vo;

import com.bxm.newidea.component.vo.BaseBean;

import java.util.Date;

/**
 * Created by Arei on 2018/10/19.
 */
public class PrivilegeVO extends BaseBean {
    private Long id;
    private String title;
    private Date startTime;
    private Date endTime;
    private Long order;
    private Long merchantId;
    private Long commodityId;
    private Integer status;
    private Integer deleteFlag;
    private Date addTime;
    private Long participantCount;
    private Long imgUrl;
    private String thumbnailUrl;
    private String shareBgUrl;
    private String content;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Long getOrder() {
        return order;
    }

    public void setOrder(Long order) {
        this.order = order;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }

    public Long getCommodityId() {
        return commodityId;
    }

    public void setCommodityId(Long commodityId) {
        this.commodityId = commodityId;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getDeleteFlag() {
        return deleteFlag;
    }

    public void setDeleteFlag(Integer deleteFlag) {
        this.deleteFlag = deleteFlag;
    }

    public Date getAddTime() {
        return addTime;
    }

    public void setAddTime(Date addTime) {
        this.addTime = addTime;
    }

    public Long getParticipantCount() {
        return participantCount;
    }

    public void setParticipantCount(Long participantCount) {
        this.participantCount = participantCount;
    }

    public Long getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(Long imgUrl) {
        this.imgUrl = imgUrl;
    }

    public String getThumbnailUrl() {
        return thumbnailUrl;
    }

    public void setThumbnailUrl(String thumbnailUrl) {
        this.thumbnailUrl = thumbnailUrl;
    }

    public String getShareBgUrl() {
        return shareBgUrl;
    }

    public void setShareBgUrl(String shareBgUrl) {
        this.shareBgUrl = shareBgUrl;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
}

==> localnews-activity-model-2.0.3-sources.jar: com/bxm/localnews/activity/vo/PrivilegeVO.java <==
package com.bxm.localnews.activity.vo;

import com.bxm.newidea.component.vo.BaseBean;

import java.util.Date;

/**
 * Created by Arei on 2018/10/19.
 */
public class PrivilegeVO extends BaseBean {
    private Long id;
    private String title;
    private Date startTime;
    private Date endTime;
    private Long order;
    private Long merchantId;
    private Long commodityId;
    private Integer status;
    private Integer deleteFlag;
    private Date addTime;
    private Long participantCount;
    private Long imgUrl;
    private String thumbnailUrl;
    private String shareBgUrl;
    private String content;
    private String discount;
    private String businessStartTime;
    private String businessEndTime;

    public String getBusinessStartTime() {
        return businessStartTime;
    }

    public void setBusinessStartTime(String businessStartTime) {
        this.businessStartTime = businessStartTime;
    }

    public String getBusinessEndTime() {
        return businessEndTime;
    }

    public void setBusinessEndTime(String businessEndTime) {
        this.businessEndTime = businessEndTime;
    }

    public String getDiscount() {
        return discount;
    }

    public void setDiscount(String discount) {
        this.discount = discount;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Long getOrder() {
        return order;
    }

    public void setOrder(Long order) {
        this.order = order;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }

    public Long getCommodityId() {
        return commodityId;
    }

    public void setCommodityId(Long commodityId) {
        this.commodityId = commodityId;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getDeleteFlag() {
        return deleteFlag;
    }

    public void setDeleteFlag(Integer deleteFlag) {
        this.deleteFlag = deleteFlag;
    }

    public Date getAddTime() {
        return addTime;
    }

    public void setAddTime(Date addTime) {
        this.addTime = addTime;
    }

    public Long getParticipantCount() {
        return participantCount;
    }

    public void setParticipantCount(Long participantCount) {
        this.participantCount = participantCount;
    }

    public Long getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(Long imgUrl) {
        this.imgUrl = imgUrl;
    }

    public String getThumbnailUrl() {
        return thumbnailUrl;
    }

    public void setThumbnailUrl(String thumbnailUrl) {
        this.thumbnailUrl = thumbnailUrl;
    }

    public String getShareBgUrl() {
        return shareBgUrl;
    }

    public void setShareBgUrl(String shareBgUrl) {
        this.shareBgUrl = shareBgUrl;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }
}
